Format generated Go source code in-process
[govpp.git] / govpp.go
index ff45b78..f36ce40 100644 (file)
--- a/govpp.go
+++ b/govpp.go
 package govpp
 
 import (
+       "time"
+
        "git.fd.io/govpp.git/adapter"
-       "git.fd.io/govpp.git/adapter/vppapiclient"
+       "git.fd.io/govpp.git/adapter/socketclient"
        "git.fd.io/govpp.git/core"
 )
 
-var vppAdapter adapter.VppAdapter // VPP Adapter that will be used in the subsequent Connect calls
+var (
+       // VPP binary API adapter that will be used in the subsequent Connect calls
+       vppAdapter adapter.VppAPI
+)
+
+func getVppAdapter(addr string) adapter.VppAPI {
+       if vppAdapter == nil {
+               vppAdapter = socketclient.NewVppClient(addr)
+       }
+       return vppAdapter
+}
+
+// SetVppAdapter sets the adapter that will be used for connections to VPP in the subsequent `Connect` calls.
+func SetVppAdapter(a adapter.VppAPI) {
+       vppAdapter = a
+}
 
 // Connect connects the govpp core to VPP either using the default VPP Adapter, or using the adapter previously
 // set by SetAdapter (useful mostly just for unit/integration tests with mocked VPP adapter).
 // This call blocks until VPP is connected, or an error occurs. Only one connection attempt will be performed.
 func Connect(shm string) (*core.Connection, error) {
-       if vppAdapter == nil {
-               vppAdapter = vppapiclient.NewVppAdapter(shm)
-       }
-       return core.Connect(vppAdapter)
+       return core.Connect(getVppAdapter(shm))
 }
 
 // AsyncConnect asynchronously connects the govpp core to VPP either using the default VPP Adapter,
@@ -37,14 +51,6 @@ func Connect(shm string) (*core.Connection, error) {
 // This call does not block until connection is established, it returns immediately. The caller is
 // supposed to watch the returned ConnectionState channel for Connected/Disconnected events.
 // In case of disconnect, the library will asynchronously try to reconnect.
-func AsyncConnect(shm string) (*core.Connection, chan core.ConnectionEvent, error) {
-       if vppAdapter == nil {
-               vppAdapter = vppapiclient.NewVppAdapter(shm)
-       }
-       return core.AsyncConnect(vppAdapter)
+func AsyncConnect(shm string, attempts int, interval time.Duration) (*core.Connection, chan core.ConnectionEvent, error) {
+       return core.AsyncConnect(getVppAdapter(shm), attempts, interval)
 }
-
-// SetAdapter sets the adapter that will be used for connections to VPP in the subsequent `Connect` calls.
-func SetAdapter(ad adapter.VppAdapter) {
-       vppAdapter = ad
-}
\ No newline at end of file